@@ -1,6 +1,4 @@
 
-context("session_info")
-
 test_that("session_info", {
   info <- readRDS(paste0("fixtures/devtools-info-", .Platform$OS.type, ".rda"))
   mockery::stub(session_info, "package_info", pi)
@@ -12,6 +10,6 @@ test_that("session_info", {
 
 test_that("print.session_info", {
   si <- session_info()
-  expect_output(print(si), "setting  value", fixed = TRUE)
-  expect_output(print(si), "package[ ]+\\* version[ ]+date[ ]+lib[ ]+source")
+  expect_output(print(si), "setting[ ]+value")
+  expect_output(print(si), "package[ ]+\\* version[ ]+date[ ][(]UTC[)][ ]+lib[ ]+source")
 })
